@@ -727,6 +727,13 @@ class DsoEncoder(json.JSONEncoder):
                                               'H-band': obj.magnitudes[3],
                                               'K-band': obj.magnitudes[4],
                                               },
+                               'from external catalog': obj.notngc,
+                               'parallax': obj.parallax,
+                               'proper motion': {'right ascension': obj.pm_ra,
+                                                 'declination': obj.pm_dec,
+                                                 },
+                               'radial velocity': obj.radvel,
+                               'redshift': obj.redshift,
                                'other identifiers': {'messier': obj.identifiers[0],
                                                      'NGC': obj.identifiers[1],
                                                      'IC': obj.identifiers[2],
@@ -1540,7 +1547,7 @@ def printDetails(dso: Union[Dso, str]) -> str:
 
     obj_string += (f'|{" " * 77}|\n')
 
-    redshift = f'{dso.redshift:.6f}'
+    redshift = f'{dso.redshift:.6f}' if dso.redshift is not None else None
     obj_string += ('| '
                    f'Parallax: {_add_units(dso.parallax, "mas"):13}'
                    f'Radial velocity: {_add_units(dso.radvel, "km/s"):14}'
